@@ -1,12 +1,12 @@
 /* Common subexpression elimination for GNU compiler.
    Copyright (C) 1987, 1988, 1989, 1992, 1993, 1994, 1995, 1996, 1997, 1998,
-   1999, 2003, 2004 Free Software Foundation, Inc.
+   1999, 2003, 2004, 2005, 2007 Free Software Foundation, Inc.
 
 This file is part of GCC.
 
 GCC is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
-Software Foundation; either version 2, or (at your option) any later
+Software Foundation; either version 3, or (at your option) any later
 version.
 
 GCC is distributed in the hope that it will be useful, but WITHOUT ANY
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with GCC; see the file COPYING.  If not, write to the Free
-Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-02111-1307, USA.  */
+along with GCC; see the file COPYING3.  If not see
+<http://www.gnu.org/licenses/>.  */
 
 /* Describe a value.  */
 typedef struct cselib_val_struct GTY(())
@@ -29,7 +28,7 @@ typedef struct cselib_val_struct GTY(())
     /* A VALUE rtx that points back to this structure.  */
     rtx GTY ((tag ("1"))) val_rtx;
     /* Used to keep a list of free cselib_val structures.  */
-    struct cselib_val_struct * GTY ((skip (""))) next_free;
+    struct cselib_val_struct * GTY ((skip)) next_free;
   } GTY ((desc ("1"))) u;
 
   /* All rtl expressions that hold this value at the current time during a
@@ -49,7 +48,6 @@ struct elt_loc_list GTY(())
   struct elt_loc_list *next;
   /* An rtl expression that holds the value.  */
   rtx loc;
-  rtx canon_loc;
   /* The insn that made the equivalence.  */
   rtx setting_insn;
   /* True when setting insn is inside libcall.  */
@@ -64,11 +62,12 @@ struct elt_list GTY(())
 };
 
 extern cselib_val *cselib_lookup (rtx, enum machine_mode, int);
-extern void cselib_update_varray_sizes (void);
-extern void cselib_init (void);
+extern void cselib_init (bool record_memory);
+extern void cselib_clear_table (void);
 extern void cselib_finish (void);
 extern void cselib_process_insn (rtx);
 extern enum machine_mode cselib_reg_set_mode (rtx);
 extern int rtx_equal_for_cselib_p (rtx, rtx);
 extern int references_value_p (rtx, int);
 extern rtx cselib_subst_to_values (rtx);
+extern void cselib_invalidate_rtx (rtx);
